<?php
/**
 * Plugin Name: Woocommerce RuKassa payment gateway
 * Plugin URI:  #
 * Description: RuKassa universal payment API integration for Woocommerce (Based on QIWI WC)
 * Version:     0.2.0
 * Author:      RuKassa
 * Author URI:  https://lk.rukassa.is/
 * License:     MIT
 * License URI: https://www.gnu.org/licenses/mit.html
 * Text Domain: woocommerce_payment_rukassa
 * Domain Path: /languages
 * Depends:     WooCommerce
 *
 * @package woocommerce-payment-rukassa
 */

defined( 'ABSPATH' ) || exit;

// On Woocommerce ready.
add_action( 'woocommerce_init', function () {

	// Require plugin function's.
	if ( ! function_exists( 'get_plugin_data' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}

	/**
	 * Plugin data.
	 *
	 * @var array $data
	 */
	$data = get_plugin_data( __FILE__, true, true );

	// Translations.
	load_plugin_textdomain( 'woocommerce_payment_rukassa', false, basename( __DIR__ ) . $data['DomainPath'] );

	/**
	 * The client name.
	 *
	 * @var string CLIENT_NAME
	 */
	if ( ! defined( 'CLIENT_NAME' ) ) {
		define( 'CLIENT_NAME', 'WordPress Woccomerce' );
	}

	/**
	 * The client version.
	 *
	 * @var string CLIENT_VERSION
	 */
	if ( ! defined( 'CLIENT_VERSION' ) ) {
		define( 'CLIENT_VERSION', $data['Version'] );
	}

	// Autoload for standalone composer build or composer's WordPress instalations.
	if ( ! class_exists( 'Curl\Curl' ) ) {
		require_once __DIR__ . DIRECTORY_SEPARATOR . 'vendor' . DIRECTORY_SEPARATOR . 'curl' . DIRECTORY_SEPARATOR . 'curl' . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'Curl' . DIRECTORY_SEPARATOR . 'Curl.php';
	}

	if ( ! class_exists( 'RuKassa\Payment\Gateway' ) ) {
		require_once __DIR__ . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'class-gateway.php';
	}

	// Ready for use or noticie broken installation.
	if ( class_exists( 'RuKassa\Payment\Gateway' ) ) {
		// Add menu link.
		add_action( 'admin_menu', function () {
			/*
			 * translators:
			 * ru_RU: RuKassa Касса
			 */
			$title = __( 'RuKassa Settings', 'woocommerce_payment_rukassa' );
			add_submenu_page( 'woocommerce', $title, $title, 'manage_woocommerce', 'admin.php?page=wc-settings&tab=checkout&section=rukassa' );
		}, 51 );

		// Add gateway.
		add_filter( 'woocommerce_payment_gateways', function ( $methods ) {
			$methods[] = \RuKassa\Payment\Gateway::class;
			return $methods;
		} );
	} else {
		add_action( 'admin_notices', function () use ( $data ) {
			printf(

				/*
				 * translators:
				 * ru_RU: <div class="error"><p><strong>Ошибка:</strong> плагин «%1$s» установлен неправильно.</p><p>Пожалуйста, ознакомьтесь с инструкциями по <a href="%2$s" target="_blank">установке в ручную</a>.</p></div>
				 * %1$s: Localised plugin name
				 * %2$s: URL to instalation manual
				 */
				__( '<div class="error"><p><strong>Error:</strong> Plugin "%1$s" is not installed correctly.</p><p>Please, see instructions for <a href="%2$s" target="_blank">manual instalation</a>.</p></div>', 'woocommerce_payment_rukassa' ),
				esc_html( $data['Name'] ),
				esc_url( $data['PluginURI'] . '#manual-installation' )
			); // WPCS: XSS OK.
		} );
	}

} );
